<div align="center">

![](docs/source/_static/images/dashtools_logo_w_blk_bkg.png)

<h3>
<b><i>Create, Run and Deploy Plotly Dash Apps from Terminal</i></b>
</h3>

[![GitHub](https://img.shields.io/github/stars/andrew-hossack/dash-tools?style=flat-square)](https://github.com/andrew-hossack/dash-tools) | [![Pypi](https://img.shields.io/pypi/v/dash-tools?style=flat-square)](https://pypi.org/project/dash-tools/) | [![Downloads](https://pepy.tech/badge/dash-tools)](https://pepy.tech/project/dash-tools) | ![Build and Test](https://img.shields.io/github/workflow/status/andrew-hossack/dash-tools/Build%20and%20Test%20on%20Push%20or%20PR?label=Build%20and%20Test) | ![License](https://img.shields.io/github/license/andrew-hossack/dash-tools)

</div>

DashTools is an open-source command line toolchain for Plotly Dash that makes creating and deploying dash projects to Heroku intuitive and easy.

## Use dashtools to...

- **Create templated dash apps** with one command
- **Deploy your app** to Heroku in under a minute
- **Generate Procfile, requirements.txt and runtime.txt** automatically on deploy
- **Many boilerplate templates** for creating apps
- **Dockerize your app** in a single step

## [Visit the Official DashTools Documentation Site](https://dash-tools.readthedocs.io/en/latest/index.html)
